server_client_20150129_153949

### config1 : test_client_isolation

Result | Function execution time | Total execution time
--- | --- | ---
Failed | 2.36799407005 sec | 5.6381778717 sec

Error message: Did not properly handle faulty client

Naarad report

### Metrics

#### server1-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
latency | 1.09 | 0.35 | 0.26 | 0.32 | 0.4 | 0.43 | 0.46 | 0.75 | 0.098
qps | 403.00 | 403.00 | 403.00 | 403.00 | 403.00 | 403.00 | 403.00 | 403.00 | 0.0

### SLAs

metric | submetric | sla rule | value
--- | --- | --- | ---
server1-perf | latency | p50 lt 0.3 | 0.319
server1-perf | latency | mean lt 0.33 | 0.351240694789
server1-perf | qps | mean lt 7.0 | 403.0
server2-perf | latency | p50 lt 0.3 | None
server2-perf | latency | mean lt 0.33 | None
server2-perf | qps | mean lt 7.0 | None
server3-perf | latency | p50 lt 0.3 | None
server3-perf | latency | mean lt 0.33 | None
server3-perf | qps | mean lt 7.0 | None
client1-perf | latency | p50 lt 22.0 | None
client1-perf | latency | mean lt 35.0 | None
client1-perf | qps | mean lt 2.0 | None
client2-perf | latency | p50 lt 22.0 | None
client2-perf | latency | mean lt 35.0 | None
client2-perf | qps | mean lt 2.0 | None